Rock
====

Rock Platform tool.

This is a command line tool that simplifies building, testing, and running
applications on the Rock Platform.

## License

This work is licensed under the MIT License (see the LICENSE file).
